==> brand_colors-0.0.1.tar.gz: lib/brand_colors.dart <==
library brand_colors;

import 'dart:ui';

class BrandColors {
  // Facebook
  static const Color facebookBlue = Color(0xff1877f2);
  static const Color facebookDarkBlue = Color(0xff3b5998);

  // Twitter
  static const Color twitterBlue = Color(0xff1da1f2);
  static const Color twitterBlack = Color(0xff14171a);
  static const Color twitterDarkGrey = Color(0xffaab8c2);
  static const Color twitterGrey = Color(0xffe1e8ed);
  static const Color twitterWhite = Color(0xfff5f8fa);

  // YouTube
  static const Color youTubeRed = Color(0xffff0000);
  static const Color youTubeBlack = Color(0xff282828);
  static const Color youTubeWhite = Color(0xffffffff);

  // Instagram
  static const Color instagramMagenta = Color(0xffc32aa3);
  static const Color instagramBlue = Color(0xff4c5fd7);
  static const Color instagramPurple = Color(0xff7232bd);
  static const Color instagramOrange = Color(0xfff46f30);
  static const Color instagramYellow = Color(0xffffdc7d);

  // Pinterest
  static const Color pinterestRed = Color(0xffbd081c);

  // LinkedIn
  static const Color linkedInBlue = Color(0xffff0000);
  static const Color linkedInLightBlue = Color(0xff00a0dc);
  static const Color linkedInBlack = Color(0xff000000);
  static const Color linkedInWhite = Color(0xffffffff);

  // Google
  static const Color googleBlue = Color(0xff4285f4);
  static const Color googleGreen = Color(0xff34a853);
  static const Color googleRed = Color(0xffea4335);
  static const Color googleYellow = Color(0xfffbbc05);

  // Snapchat
  static const Color snapchatYellow = Color(0xfffffc00);
  static const Color snapchatBlack = Color(0xff000000);
  static const Color snapchatWhite = Color(0xffffffff);

  // Whatsapp
  static const Color whatsAppGreen = Color(0xff25d366);
  static const Color whatsAppDarkGreen = Color(0xff075e54);
  static const Color whatsAppGreenBlue = Color(0xff128c7e);
  static const Color whatsAppLightGreen = Color(0xffdcf8c6);
  static const Color whatsAppBlue = Color(0xff34b7f1);

  // Tumblr
  static const Color tumblrBlue = Color(0xff35465d);

  // Reddit
  static const Color redditOrange = Color(0xffff4500);
  static const Color redditRedOrange = Color(0xffff5700);
  static const Color redditSkyBlue = Color(0xffcee3f8);
  static const Color redditBlue = Color(0xff336699);
  static const Color redditLightBlue = Color(0xff5f99cf);

  // Mastodon
  static const Color mastodonBlue = Color(0xff2b90d9);
  static const Color mastodonBlack = Color(0xff282c37);
  static const Color mastodonGrey = Color(0xff9baec8);
  static const Color mastodonLightGrey = Color(0xffd9e1e8);

  // Spotify
  static const Color spotifyGreen = Color(0xff1ed760);
  static const Color spotifyDarkGreen = Color(0xff1db954);
  static const Color spotifyWhite = Color(0xffffffff);
  static const Color spotifyBlack = Color(0xff191414);

  // Apple
  static const Color appleGrey = Color(0xffa6b1b7);
  static const Color appleDarkGrey = Color(0xff333333);
  static const Color appleLightGrey = Color(0xffbbbbbb);
  static const Color appleBlack = Color(0xff000000);
  static const Color appleWhite = Color(0xffffffff);

  // Amazon
  static const Color amazonOrange = Color(0xffff9900);

  // Microsoft
  static const Color microsoftRed = Color(0xfff35022);
  static const Color microsoftGreen = Color(0xff80bb03);
  static const Color microsoftBlue = Color(0xff03a5f0);
  static const Color microsoftYellow = Color(0xffffb903);

  // Periscope
  static const Color periscopeBlue = Color(0xff40a4c4);
  static const Color periscopeRedOrange = Color(0xffd55548);
  static const Color periscopeLightBlue = Color(0xff7cd6f1);
  static const Color periscopeDarkBlue = Color(0xff3f4d51);
  static const Color periscopeGrey = Color(0xffa4b8be);

  // Foursquare
  static const Color foursquarePink = Color(0xfff94877);
  static const Color foursquareNavy = Color(0xff073282);
  static const Color foursquareBlue = Color(0xff2d5be3);

  // Swarm
  static const Color swarmOrangePrimary = Color(0xffffa633);
  static const Color swarmOrange2 = Color(0xffffa71c);
  static const Color swarmDarkOrange = Color(0xfff06d1b);
  static const Color swarmBlue = Color(0xff2182eb);

  // Medium
  static const Color mediumGreen = Color(0xff02b875);
  static const Color mediumDarkGreen = Color(0xff00ab6b);
  static const Color mediumLightGreen = Color(0xffe8f3ec);
  static const Color mediumBlack = Color(0xff12100e);
  static const Color mediumWhite = Color(0xffffffff);

  // Vimeo
  static const Color vimeoBlue = Color(0xff1ab7ea);
  static const Color vimeoBlack = Color(0xff162221);
  static const Color vimeoPureBlack = Color(0xff000000);
  static const Color vimeoWhite = Color(0xffffffff);

  // Skype
  static const Color skypeBlue = Color(0xff00aff0);
  static const Color skypeDarkBlue = Color(0xff0078d7);

  // Android
  static const Color androidGreen = Color(0xffa4c639);

  // Quora
  static const Color quoraMaroon = Color(0xffaa2200);
  static const Color quoraBlue = Color(0xff2b6dad);
  static const Color quoraWhite = Color(0xffffffff);

  // Dribbble
  static const Color dribbblePink = Color(0xffea4c89);
  static const Color dribbbleDarkPink = Color(0xffc32361);
  static const Color dribbbleDarkGrey = Color(0xff444444);
  static const Color dribbbleGrey = Color(0xff9ba5a8);

  // Slack
  static const Color slackPurple = Color(0xff4a154b);
  static const Color slackBlue = Color(0xff36c5f0);
  static const Color slackGreen = Color(0xff2eb67d);
  static const Color slackRed = Color(0xffe01e5a);
  static const Color slackYellow = Color(0xffecb22e);

  // StumbleUpon
  static const Color stumbleUponOrangePrimary = Color(0xffe94826);
  static const Color stumbleUponOrange2 = Color(0xffeb4924);
  static const Color stumbleUponWhite = Color(0xffe4e5e7);
  static const Color stumbleUponBlack = Color(0xff000000);

  // Flickr
  static const Color flickrPinkPrimary = Color(0xfff40083);
  static const Color flickrPink2 = Color(0xffff1981);
  static const Color flickrPink3 = Color(0xffff0084);
  static const Color flickrBluePrimary = Color(0xff006add);
  static const Color flickrBlue2 = Color(0xff177fff);
  static const Color flickrBlue3 = Color(0xff246dd6);

  // Yahoo
  static const Color yahooPurplePrimary = Color(0xff430297);
  static const Color yahooPurple2 = Color(0xff500095);
  static const Color yahooPurple3 = Color(0xff3b009d);
  static const Color yahooPurple4 = Color(0xff38027c);
  static const Color yahooDarkPurple = Color(0xff2d1152);

  // Twitch
  static const Color twitchPurple = Color(0xff6441a4);
  static const Color twitchLightPurple1 = Color(0xffb9a3e3);
  static const Color twitchLightPurple2 = Color(0xffd7caf5);
  static const Color twitchBlack = Color(0xff292929);
  static const Color twitchPureBlack = Color(0xff000000);

  // Soundcloud
  static const Color soundCloudOrangePrimary = Color(0xffff5500);
  static const Color soundCloudOrange2 = Color(0xffff4B00);
  static const Color soundCloudOrange3 = Color(0xffff3801);
  static const Color soundCloudDarkOrange = Color(0xffff3300);
  static const Color soundCloudLightOrange = Color(0xffff7700);

  // DeviantArt
  static const Color deviantArtGreen = Color(0xff05cc47);
  static const Color deviantArtDarkGreen1 = Color(0xff1f3626);
  static const Color deviantArtDarkGreen2 = Color(0xff42704f);
  static const Color deviantArtLightGreen = Color(0xff4dc47d);
  static const Color deviantArtLightGreen2 = Color(0xffd4f5de);

  // ! Pocket
  static const Color pocketPink = Color(0xffee4056);

  // SlideShare
  static const Color slideShareBlue = Color(0xff00a0dc);
  static const Color slideShareDarkBlue = Color(0xffe68523);
  static const Color slideShareOrange = Color(0xff0077b5);

  // ! 500px
  static const Color fiveHundredPxBlue = Color(0xff0099e5);

  // ! Vk
  static const Color vkBlue = Color(0xff4a76a8);

  // ! Steam
  static const Color steamNavy = Color(0xff171A21);

  // ! Discord
  static const Color discordBlurple = Color(0xff7289da);

  // Telegram
  static const Color telegramBlue = Color(0xff0088cc);

  // Clarity
  static const Color clarityBlue = Color(0xff61bed9);

  // ! Listly
  static const Color listlyOrange = Color(0xffdf6d46);

  // ! Git
  static const Color gitBlack = Color(0xff333333);

  // Viber
  static const Color viberPurple = Color(0xff665cac);

  // Google+
  static const Color googlePlusRed = Color(0xffdb4437);

  // Vine
  static const Color vineGreen = Color(0xff00b489);
}

==> brand_colors-0.0.3.tar.gz: lib/brand_colors.dart <==
library brand_colors;

import 'dart:ui';

class BrandColors {
  // Facebook
  static const Color facebookBlue = Color(0xff1877f2);
  static const Color facebookDarkBlue = Color(0xff3b5998);

  // Twitter
  static const Color twitterBlue = Color(0xff1da1f2);
  static const Color twitterBlack = Color(0xff14171a);
  static const Color twitterDarkGray = Color(0xffaab8c2);
  static const Color twitterGray = Color(0xffe1e8ed);
  static const Color twitterWhite = Color(0xfff5f8fa);

  // YouTube
  static const Color youTubeRed = Color(0xffff0000);
  static const Color youTubeBlack = Color(0xff282828);
  static const Color youTubeWhite = Color(0xffffffff);

  // Instagram
  static const Color instagramMagenta = Color(0xffc32aa3);
  static const Color instagramBlue = Color(0xff4c5fd7);
  static const Color instagramPurple = Color(0xff7232bd);
  static const Color instagramOrange = Color(0xfff46f30);
  static const Color instagramYellow = Color(0xffffdc7d);

  // Pinterest
  static const Color pinterestRed = Color(0xffbd081c);

  // LinkedIn
  static const Color linkedInBlue = Color(0xffff0000);
  static const Color linkedInLightBlue = Color(0xff00a0dc);
  static const Color linkedInBlack = Color(0xff000000);
  static const Color linkedInWhite = Color(0xffffffff);

  // Google
  static const Color googleBlue = Color(0xff4285f4);
  static const Color googleGreen = Color(0xff34a853);
  static const Color googleRed = Color(0xffea4335);
  static const Color googleYellow = Color(0xfffbbc05);

  // Snapchat
  static const Color snapchatYellow = Color(0xfffffc00);
  static const Color snapchatBlack = Color(0xff000000);
  static const Color snapchatWhite = Color(0xffffffff);

  // Whatsapp
  static const Color whatsAppGreen = Color(0xff25d366);
  static const Color whatsAppDarkGreen = Color(0xff075e54);
  static const Color whatsAppGreenBlue = Color(0xff128c7e);
  static const Color whatsAppLightGreen = Color(0xffdcf8c6);
  static const Color whatsAppBlue = Color(0xff34b7f1);

  // Tumblr
  static const Color tumblrBlue = Color(0xff35465d);

  // Reddit
  static const Color redditOrange = Color(0xffff4500);
  static const Color redditRedOrange = Color(0xffff5700);
  static const Color redditSkyBlue = Color(0xffcee3f8);
  static const Color redditBlue = Color(0xff336699);
  static const Color redditLightBlue = Color(0xff5f99cf);

  // Mastodon
  static const Color mastodonBlue = Color(0xff2b90d9);
  static const Color mastodonBlack = Color(0xff282c37);
  static const Color mastodonGray = Color(0xff9baec8);
  static const Color mastodonLightGray = Color(0xffd9e1e8);

  // Spotify
  static const Color spotifyGreen = Color(0xff1ed760);
  static const Color spotifyDarkGreen = Color(0xff1db954);
  static const Color spotifyWhite = Color(0xffffffff);
  static const Color spotifyBlack = Color(0xff191414);

  // Apple
  static const Color appleGray = Color(0xffa6b1b7);
  static const Color appleDarkGray = Color(0xff333333);
  static const Color appleLightGray = Color(0xffbbbbbb);
  static const Color appleBlack = Color(0xff000000);
  static const Color appleWhite = Color(0xffffffff);

  // Amazon
  static const Color amazonOrange = Color(0xffff9900);
  static const Color amazonBlue = Color(0xff146eb4);

  // Microsoft
  static const Color microsoftRed = Color(0xfff35022);
  static const Color microsoftGreen = Color(0xff80bb03);
  static const Color microsoftBlue = Color(0xff03a5f0);
  static const Color microsoftYellow = Color(0xffffb903);

  // Periscope
  static const Color periscopeBlue = Color(0xff40a4c4);
  static const Color periscopeRedOrange = Color(0xffd55548);
  static const Color periscopeLightBlue = Color(0xff7cd6f1);
  static const Color periscopeDarkBlue = Color(0xff3f4d51);
  static const Color periscopeGray = Color(0xffa4b8be);

  // Foursquare
  static const Color foursquarePink = Color(0xfff94877);
  static const Color foursquareNavy = Color(0xff073282);
  static const Color foursquareBlue = Color(0xff2d5be3);

  // Swarm
  static const Color swarmOrangePrimary = Color(0xffffa633);
  static const Color swarmOrange2 = Color(0xffffa71c);
  static const Color swarmDarkOrange = Color(0xfff06d1b);
  static const Color swarmBlue = Color(0xff2182eb);

  // Medium
  static const Color mediumGreen = Color(0xff02b875);
  static const Color mediumDarkGreen = Color(0xff00ab6b);
  static const Color mediumLightGreen = Color(0xffe8f3ec);
  static const Color mediumBlack = Color(0xff12100e);
  static const Color mediumWhite = Color(0xffffffff);

  // Vimeo
  static const Color vimeoBlue = Color(0xff1ab7ea);
  static const Color vimeoBlack = Color(0xff162221);
  static const Color vimeoPureBlack = Color(0xff000000);
  static const Color vimeoWhite = Color(0xffffffff);

  // Skype
  static const Color skypeBlue = Color(0xff00aff0);
  static const Color skypeDarkBlue = Color(0xff0078d7);

  // Android
  static const Color androidGreen = Color(0xffa4c639);

  // Quora
  static const Color quoraMaroon = Color(0xffaa2200);
  static const Color quoraBlue = Color(0xff2b6dad);
  static const Color quoraWhite = Color(0xffffffff);

  // Dribbble
  static const Color dribbblePink = Color(0xffea4c89);
  static const Color dribbbleDarkPink = Color(0xffc32361);
  static const Color dribbbleDarkGray = Color(0xff444444);
  static const Color dribbbleGray = Color(0xff9ba5a8);

  // Slack
  static const Color slackPurple = Color(0xff4a154b);
  static const Color slackBlue = Color(0xff36c5f0);
  static const Color slackGreen = Color(0xff2eb67d);
  static const Color slackRed = Color(0xffe01e5a);
  static const Color slackYellow = Color(0xffecb22e);

  // StumbleUpon
  static const Color stumbleUponOrangePrimary = Color(0xffe94826);
  static const Color stumbleUponOrange2 = Color(0xffeb4924);
  static const Color stumbleUponWhite = Color(0xffe4e5e7);
  static const Color stumbleUponBlack = Color(0xff000000);

  // Flickr
  static const Color flickrPinkPrimary = Color(0xfff40083);
  static const Color flickrPink2 = Color(0xffff1981);
  static const Color flickrPink3 = Color(0xffff0084);
  static const Color flickrBluePrimary = Color(0xff006add);
  static const Color flickrBlue2 = Color(0xff177fff);
  static const Color flickrBlue3 = Color(0xff246dd6);

  // Yahoo
  static const Color yahooPurplePrimary = Color(0xff430297);
  static const Color yahooPurple2 = Color(0xff500095);
  static const Color yahooPurple3 = Color(0xff3b009d);
  static const Color yahooPurple4 = Color(0xff38027c);
  static const Color yahooDarkPurple = Color(0xff2d1152);

  // Twitch
  static const Color twitchPurple = Color(0xff6441a4);
  static const Color twitchLightPurple1 = Color(0xffb9a3e3);
  static const Color twitchLightPurple2 = Color(0xffd7caf5);
  static const Color twitchBlack = Color(0xff292929);
  static const Color twitchPureBlack = Color(0xff000000);

  // Soundcloud
  static const Color soundCloudOrangePrimary = Color(0xffff5500);
  static const Color soundCloudOrange2 = Color(0xffff4B00);
  static const Color soundCloudOrange3 = Color(0xffff3801);
  static const Color soundCloudDarkOrange = Color(0xffff3300);
  static const Color soundCloudLightOrange = Color(0xffff7700);

  // DeviantArt
  static const Color deviantArtGreen = Color(0xff05cc47);
  static const Color deviantArtDarkGreen1 = Color(0xff1f3626);
  static const Color deviantArtDarkGreen2 = Color(0xff42704f);
  static const Color deviantArtLightGreen = Color(0xff4dc47d);
  static const Color deviantArtLightGreen2 = Color(0xffd4f5de);

  // Pocket
  static const Color pocketPinkPrimary = Color(0xffee4056);
  static const Color pocketPink2 = Color(0xffef3e56);
  static const Color pocketTeal1 = Color(0xff42b7b0);
  static const Color pocketTeal2 = Color(0xff50bcb6);
  static const Color pocketLightTeal = Color(0xff9bcfcc);
  static const Color pocketLightGreen = Color(0xff83edb8);
  static const Color pocketOrange = Color(0xfffcb643);

  // SlideShare
  static const Color slideShareBlue = Color(0xff00a0dc);
  static const Color slideShareDarkBlue = Color(0xffe68523);
  static const Color slideShareOrange = Color(0xff0077b5);

  // 500px
  static const Color fiveHundredPxBlue = Color(0xff0099e5);
  static const Color fiveHundredPxBlack = Color(0xff222222);
  static const Color fiveHundredPxWhite = Color(0xffffffff);

  // Vk
  static const Color vkBluePrimary = Color(0xff4a76a8);
  static const Color vkBlue2 = Color(0xff4a76a8);
  static const Color vkDarkBlue = Color(0xff2a5885);
  static const Color vkDirtyWhite = Color(0xffedeef0);
  static const Color vkWhite = Color(0xfff7f8fa);

  // Steam
  static const Color steamBlack = Color(0xff171A21);
  static const Color steamNavy = Color(0xff1b2838);
  static const Color steamLightBlue = Color(0xff66c0f4);
  static const Color steamDarkBlue = Color(0xff2a475e);
  static const Color steamGray = Color(0xffc7d5e0);

  // Discord
  static const Color discordBlurple = Color(0xff7289da);
  static const Color discordWhite = Color(0xffffffff);
  static const Color discordGray = Color(0xff99aab5);
  static const Color discordBlack1 = Color(0xff2c2f33);
  static const Color discordBlack2 = Color(0xff23272a);

  // Telegram
  static const Color telegramBlue = Color(0xff0088cc);

  // Clarity
  static const Color clarityBlue = Color(0xff61bed9);

  // Listly
  static const Color listlyOrange = Color(0xffdf6d46);
  static const Color listlyDarkOrange = Color(0xffce4f24);
  static const Color listlyBlue = Color(0xff52b1b3);
  static const Color listlyDarkBlue = Color(0xff409092);
  static const Color listlyBlack1 = Color(0xff333333);
  static const Color listlyBlack2 = Color(0xff222222);

  // GitHub
  static const Color gitHubBlack = Color(0xff333333);
  static const Color gitHubBlue = Color(0xff4078c0);
  static const Color gitHubGreen = Color(0xff6cc644);
  static const Color gitHubRed = Color(0xffbd2c00);
  static const Color gitHubOrange = Color(0xffc9510c);
  static const Color gitHubPurple = Color(0xff6e5494);
  static const Color gitHubWhite = Color(0xfffafafa);
  static const Color gitHubDirtyWhite = Color(0xfff5f5f5);

  // Viber
  static const Color viberPurple = Color(0xff665cac);
  static const Color viberBlue = Color(0xff54c0d4);
  static const Color viberRed = Color(0xffef6062);
  static const Color viberYellow = Color(0xfff4eF7b);
  static const Color viberDarkGray = Color(0xff4a4a4a);
  static const Color viberGray = Color(0xffb0b0b0);
  static const Color viberWhite = Color(0xffffffff);

  // Google+
  static const Color googlePlusRed = Color(0xffdb4437);

  // Vine
  static const Color vineGreen = Color(0xff00b489);

  // Airbnb
  static const Color airbnbRed = Color(0xfffd5c63);

  // Alibaba
  static const Color alibabaOrange = Color(0xffff6a00);

  // AngularJS
  static const Color angularJsRed = Color(0xffb52e31);
  static const Color angularJsBlack = Color(0xff000000);

  // Coca-Cola
  static const Color cocaColaRed = Color(0xffed1c16);
  static const Color cocaColaVividRed = Color(0xfff40009);

  // SwipeRx
  static const Color swipeRxGreen = Color(0xff2fbca1);
  static const Color swipeRxDarkGreen = Color(0xff269781);
  static const Color swipeRxLightGreen = Color(0xffbbdce8);
  static const Color swipeRxMossGreen = Color(0xff27a18b);
  static const Color swipeRxYellow = Color(0xffffcc66);
  static const Color swipeRxBrown = Color(0xff71592d);

  // Fast food
  // McDonald's
  static const Color mcDonaldsYellow = Color(0xffffc72c);
  static const Color mcDonaldsRed = Color(0xffda291c);
  static const Color mcDonaldsBlack = Color(0xff27251f);

  // Burger King
  static const Color burgerKingRed = Color(0xffda291c);
  static const Color burgerKingBlue = Color(0xff0033a0);
  static const Color burgerKingYellow = Color(0xfff2a900);

  // Dunkin' Donuts
  static const Color dunkinDonutsOrange = Color(0xffff671f);
  static const Color dunkinDonutsMagenta = Color(0xffda1884);
  static const Color dunkinDonutsBrown = Color(0xff653819);

  // Starbucks
  static const Color starbucksGreen = Color(0xff00704a);
  static const Color starbucksBlack = Color(0xff27251f);

  // Subway
  static const Color subwayGreen = Color(0xff008c15);
  static const Color subwayMarigold = Color(0xffffc600);

  // Taco Bell
  static const Color tacoBellDarkPurple = Color(0xff702082);
  static const Color tacoBellLightPurple = Color(0xffa77bca);
  static const Color tacoBellBlack = Color(0xff000000);

  //
}
